@@ -3,5 +3,10 @@ if sys.version_info.major >= 3 and sys.version_info.minor >= 7:  # most code nee
     from .trainer.trainer_node import TrainerNode
     from .converter.converter_node import ConverterNode
 
+from .context import Context
 from .detector.detector_node import DetectorNode
+from .detector.detector import Detector
+from .model_information import ModelInformation
+from .data_classes.category import CategoryType
+from .globals import GLOBALS
 from .loop import loop
