@@ -12,7 +12,7 @@ from icecream import ic
 def default_user_input() -> UserInput:
     annotation_data = AnnotationData(
         coordinate=Point(x=0, y=0),
-        event_type=EventType.MouseDown,
+        event_type=EventType.LeftMouseDown,
         context=Context(organization='zauberzeug', project='pytest'),
         image_uuid='285a92db-bc64-240d-50c2-3212d3973566',
         category=Category(id='some_id', name='category_1', description='',
