@@ -13,7 +13,7 @@ async def upload_model(context: Context, files: List[str], model_id: str, format
         data.add_field('files',  open(file_name, 'rb'))
     async with loop.put(f'api/{context.organization}/projects/{context.project}/models/{model_id}/{format}/file', data=data) as response:
         if response.status != 200:
-            msg = f'---- could not save model with id {model_id}. Details: {response.content}'
+            msg = f'---- could not upload model with id {model_id} and format {format}. Details: {response.content}'
             raise Exception(msg)
         else:
-            logging.info(f'---- uploaded model with id {model_id}')
+            logging.info(f'---- uploaded model with id {model_id} and format {format}.')
